pub enum MoveToOutputError {
OutputDoesNotExist,
SameWindowOnTwoOutputs(Vec<WindowHandle>),
}Expand description
Error that happens when moving tags to a different output.
Variants
OutputDoesNotExist
The requested output to move the tag to, does not exist
SameWindowOnTwoOutputs(Vec<WindowHandle>)
Moving the Tag to another output would result in having the same window in multiple tags. It contains a list of windows that would be on multiple outputs.